Clazz.declarePackage("J.api.js");
Clazz.declareInterface(J.api.js, "JSmolAppletObject", javajs.api.js.JSAppletObject);
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
